@@ -118,7 +118,7 @@ impl_trait!(OrderBookTopK, DeribitWSClient, subscribe_orderbook_topk, "orderbook
 #[rustfmt::skip]
 impl_trait!(BBO, DeribitWSClient, subscribe_bbo, "bbo", to_raw_channel);
 
-fn to_candlestick_raw_channel(pair: &str, interval: u32) -> String {
+fn to_candlestick_raw_channel(pair: &str, interval: usize) -> String {
     let interval_str = match interval {
         60 => "1",
         180 => "3",
